@@ -34,4 +34,6 @@
   (Gtk HSeparator)
   (Gtk TextTagTable)
   (Gtk TextTag)
-  (Gtk TextMark)))
+  (Gtk TextMark))
+ (ignore-slots (Gtk Label) xalign yalign))
+ 
