@@ -77,7 +77,8 @@
   (Gtk SeparatorToolItem)
   (Gdk Event))
  (rejected-methods
-  append map get-style activate compare copy free)
+  append map get-style activate compare copy free get-flags delete)
  (overridden-functions
   (gtk-container-child-get-property (<gtk-container> <gtk-widget> <string>)
-                                    <object> nonpure)))
+                                    <object> nonpure))
+ (ignore-slots (Gtk Label) xalign yalign))
