@@ -1,5 +1,5 @@
 
-;; Copyright (C) 2020, 2021 Tommi Höynälänmaa
+;; Copyright (C) 2020, 2021, 2024 Tommi Höynälänmaa
 
 ;; This file is part of Theme-D-Golf.
 
@@ -38,9 +38,4 @@
   (Gtk Separator)
   (Gtk TextTagTable)
   (Gtk TextTag)
-  (Gtk TextMark))
- (overridden-functions
-  (gtk-text-buffer-insert (<gtk-text-buffer> <pointer> <string>)
-			  <none> nonpure)
-  (g-application-run (<g-application> (:uniform-list <string>))
-		     <integer> nonpure)))
+  (Gtk TextMark)))
