@@ -67,4 +67,4 @@
   (Gdk Event))
  (rejected-methods
   append map get-style activate compare copy get-cursor free
-  get-name get-state apply))
+  get-name get-state apply get-flags delete))
