@@ -851,6 +851,8 @@
             (+ i 1)))
       ((= i n-method))
       (dpl "gi-import-methods1/1")
+      (dpl i)
+      (dpl (g-base-info-get-name (get-method info i)))
       (let* ((m-info (get-method info i))
              (intf-method
               (gi-make-function-entry m-info generator str-basename)))
@@ -866,6 +868,7 @@
         (dpl "gi-import-methods1/2")
         (add-entity generator intf-method)
         (dpl "gi-import-methods1/3")
+        (dpl (slot-ref intf-method 's-target-name))
         (add-imported-function generator
                                (slot-ref intf-method 's-target-name))
         (gi-check-method m-info generator s-class-name)))
@@ -1045,6 +1048,8 @@
      '<object>)
     ((gtype)
      '<symbol>)
+    ((error)
+     '<object>)
     (else
      (raise (list 'unknown-type-tag (cons 'tag tag))))))
 
@@ -1088,9 +1093,12 @@
 
 
 (define (get-argument-type x-arg)
+  (dpl "get-argument-type")
   (let ((tag (!type-tag x-arg))
         (type-desc (!type-desc x-arg))
         (may-be-null? (!may-be-null? x-arg)))
+    (dpl tag)
+    (dpl type-desc)
     (get-target-type1 tag type-desc may-be-null? #f)))
 
 
